@@ -1,4 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 2 -*- */
+/* -*- Mode: C; c-file-style: "gnu"; tab-width: 8 -*- */
 /* Copyright (C) 2004 Carlos Garnacho
  *
  * This program is free software; you can redistribute it and/or modify
@@ -32,9 +32,6 @@ struct _GstTablePopup
 
 void  on_table_selection_changed   (GtkTreeSelection*, gpointer);
 void  on_iface_properties_clicked  (GtkWidget*, gpointer);
-void  on_activate_button_clicked   (GtkWidget*, gpointer);
-void  on_deactivate_button_clicked (GtkWidget*, gpointer);
-void  on_gateway_combo_changed     (GtkWidget*, gpointer);
 
 void  on_iface_active_changed      (GtkWidget*, gpointer);
 void  on_bootproto_changed         (GtkWidget*, gpointer);
@@ -55,6 +52,18 @@ void  on_host_aliases_dialog_changed     (GtkWidget*, gpointer);
 void  on_dialog_changed (GtkWidget*, gpointer);
 
 gboolean on_ip_address_focus_out (GtkWidget*, GdkEventFocus*, gpointer);
-gboolean callbacks_check_hostname_hook (GstDialog*, gpointer);
+
+void  on_iface_toggled  (GtkCellRendererToggle *renderer,
+			 gchar                 *path_str,
+			 gpointer               data);
+
+void     on_entry_changed      (GtkWidget     *widget,
+				gpointer       data);
+gboolean on_hostname_focus_out (GtkWidget     *widget,
+				GdkEventFocus *event,
+				gpointer       data);
+gboolean on_domain_focus_out   (GtkWidget     *widget,
+				GdkEventFocus *event,
+				gpointer       data);
 
 #endif /* __CALLBACKS_H */
