@@ -53,23 +53,22 @@ connection_get_config_method (GstConnectionDialog *dialog)
   return (ret == 1) ? OOBS_METHOD_STATIC : OOBS_METHOD_DHCP;
 }
 
-/* FIXME
 static void
-connection_set_wireless_key_type (GstConnectionDialog *dialog, GstWirelessKey key_type)
+connection_set_wireless_key_type (GstConnectionDialog *dialog,
+				  OobsWirelessKeyType  key_type)
 {
   gtk_combo_box_set_active (GTK_COMBO_BOX (dialog->key_type_combo),
-			    (key_type == GST_WIRELESS_KEY_ASCII) ? 0 : 1);
+			    (key_type == OOBS_WIRELESS_KEY_ASCII) ? 0 : 1);
 }
 
-static GstBootProto
+static OobsWirelessKeyType
 connection_get_wireless_key_type (GstConnectionDialog *dialog)
 {
   gint ret;
 
   ret = gtk_combo_box_get_active (GTK_COMBO_BOX (dialog->key_type_combo));
-  return (ret == 0) ? GST_WIRELESS_KEY_ASCII : GST_WIRELESS_KEY_HEXADECIMAL;
+  return (ret == 0) ? OOBS_WIRELESS_KEY_ASCII : OOBS_WIRELESS_KEY_HEXADECIMAL;
 }
-*/
 
 static void
 connection_essids_combo_init (GtkComboBoxEntry *combo)
@@ -147,72 +146,24 @@ ethernet_dialog_check_fields (GstConnectionDialog *dialog)
 static void
 wireless_essid_populate_model (GtkComboBox *combo, const gchar *dev)
 {
-  GtkTreeModel *model;
-  GtkTreeIter   iter;
-  xmlNodePtr    root, node;
-  xmlDoc       *doc;
-  GdkPixbuf    *locked, *unlocked, *pix;
-  gchar        *essid;
-  gboolean      encrypted;
-
-  /* FIXME
-  model = gtk_combo_box_get_model (combo);
-  gtk_list_store_clear (GTK_LIST_STORE (model));
-
-  doc   = gst_tool_run_get_directive (tool, NULL, "detect_essids", dev, NULL);
-  g_return_if_fail (doc != NULL);
-
-  locked = gtk_icon_theme_load_icon (GST_NETWORK_TOOL (tool)->icon_theme,
-				     "gnome-dev-wavelan-encrypted", 16, 0, NULL);
-  unlocked = gtk_icon_theme_load_icon (GST_NETWORK_TOOL (tool)->icon_theme,
-				       "gnome-dev-wavelan", 16, 0, NULL);
-  root  = gst_xml_doc_get_root (doc);
-
-  for (node = gst_xml_element_find_first (root, "network");
-       node; node = gst_xml_element_find_next (node, "network"))
-    {
-      essid = gst_xml_get_child_content (node, "essid");
-      encrypted = gst_xml_element_get_boolean (node, "encrypted");
-
-      pix = (encrypted) ?
-	g_object_ref (locked) :
-	g_object_ref (unlocked);
-
-      gtk_list_store_append (GTK_LIST_STORE (model), &iter);
-      gtk_list_store_set (GTK_LIST_STORE (model), &iter,
-			  0, pix, 1, essid, -1);
-
-      g_object_unref (pix);
-      g_free (essid);
-    }
-
-  g_object_unref (locked);
-  g_object_unref (unlocked);
-  */
+  /* FIXME: fill model with available ESSIDs */
 }
 
 static void
 wireless_dialog_prepare (GstConnectionDialog *dialog)
 {
-  gchar *essid, *key, *dev;
+  gchar *essid, *key;
+  OobsWirelessKeyType key_type;
 
   g_object_get (G_OBJECT (dialog->iface),
 		"essid", &essid,
 		"key", &key,
-		/* FIXME
-		"iface-wep-key-type", &key_type,
-		"iface-dev", &dev,
-		*/
+		"key-type", &key_type,
 		NULL);
 
-  /* FIXME
-     connection_set_wireless_key_type (dialog, key_type);
-  */
+  connection_set_wireless_key_type (dialog, key_type);
   gtk_entry_set_text (GTK_ENTRY (GTK_BIN (dialog->essid)->child), (essid) ? essid : "");
-
-  /* FIXME
   gtk_entry_set_text (GTK_ENTRY (dialog->wep_key), (key) ? key : "");
-  */
 
   /* FIXME
   wireless_essid_populate_model (GTK_COMBO_BOX (dialog->essid), dev);
@@ -220,9 +171,6 @@ wireless_dialog_prepare (GstConnectionDialog *dialog)
 
   g_free (essid);
   g_free (key);
-  /*
-  g_free (dev);
-  */
 }
 
 static void
@@ -231,9 +179,7 @@ wireless_dialog_save (GstConnectionDialog *dialog)
   g_object_set (G_OBJECT (dialog->iface),
 		"essid",   get_entry_text (GTK_BIN (dialog->essid)->child),
 		"key", get_entry_text (dialog->wep_key),
-		/* FIXME
-		"iface-wep-key-type", connection_get_wireless_key_type (dialog),
-		*/
+		"key-type", connection_get_wireless_key_type (dialog),
 		NULL);
 }
 
@@ -588,20 +534,7 @@ connection_check_fields (GstConnectionDialog *dialog)
 gchar*
 connection_detect_modem (void)
 {
-  xmlNodePtr  root;
-  xmlDoc     *doc;
-  gchar      *device;
-
-  /* FIXME
-  doc= gst_tool_run_get_directive (tool, NULL, "detect_modem", NULL);
-  g_return_val_if_fail (doc != NULL, NULL);
-
-  root   = gst_xml_doc_get_root (doc);
-  device = gst_xml_get_child_content (root, "device");
-  xmlFreeDoc (doc);
-	
-  return device;
-  */
+  /* FIXME: Detect modem */
   return NULL;
 }
 
