@@ -30,7 +30,7 @@ enum {
   COL_OBJECT,
   COL_DEV,
   COL_INCONSISTENT,
-  COL_HAS_GATEWAY,
+  COL_SHOW_IFACE_NAME,
   COL_LAST
 };
 
@@ -40,8 +40,7 @@ typedef enum {
 } IfaceSearchTerm;
 
 GtkTreeModel* ifaces_model_create                   (void);
-void          ifaces_model_set_interface_at_iter    (OobsIface*, GtkTreeIter*);
-void          ifaces_model_add_interface            (OobsIface*);
+void          ifaces_model_add_interface            (OobsIface*, gboolean);
 void          ifaces_model_modify_interface_at_iter (GtkTreeIter*);
 OobsIface*    ifaces_model_search_iface             (IfaceSearchTerm, const gchar*);
 void          ifaces_model_clear                    (void);
@@ -50,8 +49,4 @@ GtkTreeModelFilter* gateways_filter_model_create    (GtkTreeModel *model);
 
 GtkTreeView*  ifaces_list_create                   (GstTool *tool);
 
-GtkComboBox*  gateways_combo_create                (void);
-void          gateways_combo_select                (gchar*);
-gchar*        gateways_combo_get_selected          (void);
-
 #endif /* __IFACES_LIST_H */
