@@ -35,9 +35,6 @@ GstTool *tool;
 static GstDialogSignal signals[] = {
   /* connections tab */
   { "properties_button",            "clicked", G_CALLBACK (on_iface_properties_clicked) },
-  { "activate_button",              "clicked", G_CALLBACK (on_activate_button_clicked) },
-  { "deactivate_button",            "clicked", G_CALLBACK (on_deactivate_button_clicked) },
-  { "gateways_combo",               "changed", G_CALLBACK (on_gateway_combo_changed) },
   /* general tab */
   { "domain",                       "focus-out-event", G_CALLBACK (on_domain_focus_out) },
   { "hostname",                     "changed", G_CALLBACK (on_entry_changed) },
@@ -85,13 +82,16 @@ static GstDialogSignal signals_after[] = {
 };
 
 static void
-init_standalone_dialog (IfaceSearchTerm search_term, const gchar *term)
+init_standalone_dialog (GstTool         *tool,
+			IfaceSearchTerm  search_term,
+			const gchar     *term)
 {
   GstNetworkTool *network_tool;
   OobsIface      *iface;
   GtkWidget      *d;
 
   network_tool = GST_NETWORK_TOOL (tool);
+  gst_tool_update_gui (tool);
   iface = ifaces_model_search_iface (search_term, term);
 
   if (iface)
@@ -170,9 +170,9 @@ main (int argc, gchar *argv[])
   init_filters ();
 
   if (interface)
-    init_standalone_dialog (SEARCH_DEV, interface);
+    init_standalone_dialog (tool, SEARCH_DEV, interface);
   else if (type)
-    init_standalone_dialog (SEARCH_TYPE, type);
+    init_standalone_dialog (tool, SEARCH_TYPE, type);
   else
     gtk_widget_show (GTK_WIDGET (tool->main_dialog));
 
