@@ -36,7 +36,8 @@ static GObject* gst_network_tool_constructor (GType                  type,
 					      guint                  n_construct_properties,
 					      GObjectConstructParam *construct_params);
 
-static void gst_network_tool_update_gui (GstTool *tool);
+static void gst_network_tool_update_gui    (GstTool *tool);
+static void gst_network_tool_update_config (GstTool *tool);
 
 
 G_DEFINE_TYPE (GstNetworkTool, gst_network_tool, GST_TYPE_TOOL);
@@ -50,6 +51,7 @@ gst_network_tool_class_init (GstNetworkToolClass *class)
   object_class->constructor = gst_network_tool_constructor;
   object_class->finalize = gst_network_tool_finalize;
   tool_class->update_gui = gst_network_tool_update_gui;
+  tool_class->update_config = gst_network_tool_update_config;
 }
 
 static void
@@ -71,7 +73,6 @@ gst_network_tool_finalize (GObject *object)
   g_object_unref (tool->dns);
   g_object_unref (tool->search);
   g_object_unref (tool->interfaces_model);
-  g_object_unref (tool->gateways_model);
   g_free (tool->dialog);
 
   (* G_OBJECT_CLASS (gst_network_tool_parent_class)->finalize) (object);
@@ -134,11 +135,7 @@ gst_network_tool_constructor (GType                  type,
   tool->domain = GTK_ENTRY (widget);
 
   tool->interfaces_model = ifaces_model_create ();
-  tool->gateways_model = gateways_filter_model_create (tool->interfaces_model);
   tool->interfaces_list = ifaces_list_create (tool);
-  /* FIXME
-  tool->gateways_list = gateways_combo_create ();
-  */
   tool->host_aliases_list = host_aliases_list_create (tool);
 
   widget = gst_dialog_get_widget (GST_TOOL (tool)->main_dialog, "locations_combo");
@@ -190,13 +187,15 @@ add_interfaces (GtkTreeView *ifaces_list, OobsList *list)
   OobsListIter iter;
   GObject *iface;
   gboolean valid;
+  gint n_items;
 
   valid = oobs_list_get_iter_first (list, &iter);
+  n_items = oobs_list_get_n_items (list);
 
   while (valid)
     {
       iface = oobs_list_get (list, &iter);
-      ifaces_model_add_interface (OOBS_IFACE (iface));
+      ifaces_model_add_interface (OOBS_IFACE (iface), (n_items > 1));
 
       g_object_unref (iface);
       valid = oobs_list_iter_next (list, &iter);
@@ -227,6 +226,12 @@ add_all_interfaces (GstNetworkTool *network_tool)
   add_interfaces (network_tool->interfaces_list, ifaces_list);
 }
 
+static void
+set_entry_text (GtkWidget *entry, const gchar *text)
+{
+  gtk_entry_set_text (GTK_ENTRY (entry), (text) ? text : "");
+}
+
 static void
 gst_network_tool_update_gui (GstTool *tool)
 {
@@ -248,19 +253,28 @@ gst_network_tool_update_gui (GstTool *tool)
   update_hosts_list (hosts_list);
 
   g_signal_handlers_block_by_func (network_tool->hostname, on_entry_changed, tool->main_dialog);
-  gtk_entry_set_text (network_tool->hostname,
-		      oobs_hosts_config_get_hostname (network_tool->hosts_config));
+  set_entry_text (network_tool->hostname,
+		  oobs_hosts_config_get_hostname (network_tool->hosts_config));
   g_signal_handlers_unblock_by_func (network_tool->hostname, on_entry_changed, tool->main_dialog);
 
   g_signal_handlers_block_by_func (network_tool->domain, on_entry_changed, tool->main_dialog);
-  gtk_entry_set_text (network_tool->domain,
-		      oobs_hosts_config_get_domainname (network_tool->hosts_config));
+  set_entry_text (network_tool->domain,
+		  oobs_hosts_config_get_domainname (network_tool->hosts_config));
   g_signal_handlers_unblock_by_func (network_tool->domain, on_entry_changed, tool->main_dialog);
 
   gtk_list_store_clear (GTK_LIST_STORE (network_tool->interfaces_model));
   add_all_interfaces (network_tool);
 }
 
+static void
+gst_network_tool_update_config (GstTool *tool)
+{
+  GstNetworkTool *network_tool;
+
+  network_tool = GST_NETWORK_TOOL (tool);
+  oobs_object_update (network_tool->hosts_config);
+  oobs_object_update (network_tool->ifaces_config);
+}
 
 GstTool*
 gst_network_tool_new (void)
